/*
 * Copyright (C) 2015 Niek Linnenbank
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "USBTransferFile.h"
#include "USBController.h"

USBController::USBController(const char *path)
    : DeviceServer(path)
{
    registerFile(new USBTransferFile(this), "/transfer");
}

FileSystem::Result USBController::initialize()
{
    const FileSystem::Result r = DeviceServer::initialize();

    if (r != FileSystem::Success)
        return r;

    return FileSystem::Success;
}
